@@ -20,22 +20,6 @@ sub default : Test {
   chdir $current;
 }
 
-sub with_option : Test {
-  my $class = shift;
-
-  my $recipe = $class->load_recipe;
-
-  my $current = dir('.');
-  my $testdir = dir('t');
-
-  my $context = Module::New->setup('Module::New::ForTest');
-     $context->config->set( root => $testdir );
-  eval { $recipe->run; };
-  ok !$@ && $context->path->_root eq $testdir, $class->message('t/ is root');
-
-  chdir $current;
-}
-
 sub load_recipe {
   delete $INC{'Module/New/ForTest/Recipe/GuessRoot.pm'};
   require Module::New::ForTest::Recipe::GuessRoot;
